var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'theory.xml',
'forwardtheory.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'utility.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'faq.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'wish_list.xml',
'whats_new.xml',
'deprecated.xml',
'compare_c.xml',
'numeric_ad.xml',
'addon.xml',
'license.xml'
];
var list_down1 = [
'forwardtheory.xml',
'reversetheory.xml',
'reverse_identity.xml'
];
var list_down0 = [
'exp_forward.xml',
'log_forward.xml',
'sqrt_forward.xml',
'sin_cos_forward.xml',
'atan_forward.xml',
'asin_forward.xml',
'acos_forward.xml',
'tan_forward.xml',
'erf_forward.xml'
];
var list_current0 = [
'forwardtheory.xml#Taylor Notation',
'forwardtheory.xml#Binary Operators',
'forwardtheory.xml#Binary Operators.Addition',
'forwardtheory.xml#Binary Operators.Subtraction',
'forwardtheory.xml#Binary Operators.Multiplication',
'forwardtheory.xml#Binary Operators.Division',
'forwardtheory.xml#Standard Math Functions',
'forwardtheory.xml#Standard Math Functions.Differential Equation',
'forwardtheory.xml#Standard Math Functions.Taylor Coefficients Recursion Formula',
'forwardtheory.xml#Standard Math Functions.Cases that Apply Recursion Above',
'forwardtheory.xml#Standard Math Functions.Special Cases'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
